/*
 * Copyright (c) 2001-2003 Swedish Institute of Computer Science.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
 * SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 * This file is part of the lwIP TCP/IP stack.
 *
 * Author: Adam Dunkels <adam@sics.se>
 * Author: Stefano Oliveri <stefano.oliveri@st.com>
 *
 */
#ifndef __CC_H__
#define __CC_H__


#undef LWIP_NOASSERT//FSL

#define BYTE_ORDER LITTLE_ENDIAN

// Typedefs for the types used by lwip

typedef unsigned   char    u8_t;
typedef signed     char    s8_t;
typedef unsigned   short   u16_t;
typedef signed     short   s16_t;
typedef unsigned   int    u32_t;
typedef signed     int    s32_t;
typedef u32_t mem_ptr_t;

// Compiler hints for packing lwip's structures
//FSL: very important at high optimization level
/* */


#if __GNUC__
#define PACK_STRUCT_BEGIN
#elif defined(__IAR_SYSTEMS_ICC__)
#define PACK_STRUCT_BEGIN _Pragma("pack(1)")
#elif defined(__arm__) && defined(__ARMCC_VERSION)
#define PACK_STRUCT_BEGIN __packed
#else
#define PACK_STRUCT_BEGIN
#endif

#if __GNUC__
#define PACK_STRUCT_STRUCT __attribute__ ((__packed__))
#elif defined(__IAR_SYSTEMS_ICC__)
#define PACK_STRUCT_STRUCT
#elif defined(__arm__) && defined(__ARMCC_VERSION)
#define PACK_STRUCT_STRUCT
#else
#define PACK_STRUCT_STRUCT
#endif

#if __GNUC__
#define PACK_STRUCT_END
#elif defined(__IAR_SYSTEMS_ICC__)
#define PACK_STRUCT_END _Pragma("pack()")
#elif defined(__arm__) && defined(__ARMCC_VERSION)
#define PACK_STRUCT_END
#else
#define PACK_STRUCT_END
#endif

#define PACK_STRUCT_FIELD(x) x

// Platform specific diagnostic output
#include "sys_arch.h"//FSL

// non-fatal, print a message.
#define LWIP_PLATFORM_DIAG(x)                     do {PRINTF x;PRINTF("\r\n");} while(0)
// fatal, print message and abandon execution.
#define LWIP_PLATFORM_ASSERT(x)                   sys_assert( x )

// relocate the pbuf pools to external SDRAM
#if defined(__ICCARM__)
#define LWIP_PBUF_ATTRIBUTE _Pragma("location = \"LWIP_MEMP\"") __no_init
#elif defined(__CC_ARM)
#define LWIP_PBUF_ATTRIBUTE __attribute__((section("LWIP_MEMP"))) __attribute__((section (".noinit")))
#elif defined(__GNUC__)
#define LWIP_PBUF_ATTRIBUTE __attribute__((section("LWIP_MEMP, \"aw\", %nobits @"))) __attribute__((section (".noinit")))
#else
#define LWIP_PBUF_ATTRIBUTE
#endif

/**
 * The lwIP mem pools, redirected to external SDRAM.
 * Check in the linker input file for this area [sdram_lwip_memp_data_start : sdram_lwip_memp_data_end]
 * Size of this area should be big enough for the below buffers!
 */
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_ARP_QUEUE_base[];
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_NETBUF_base[];
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_NETCONN_base[];
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_NETDB_base[];
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_PBUF_POOL_base[];
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_PBUF_base[];
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_SYS_TIMEOUT_base[];
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_TCPIP_MSG_API_base[];
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_TCPIP_MSG_INPKT_base[];
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_TCP_PCB_LISTEN_base[];
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_TCP_PCB_base[];
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_TCP_SEG_base[];
LWIP_PBUF_ATTRIBUTE extern u8_t memp_memory_UDP_PCB_base[];

#endif /* __CC_H__ */
