/*
 * C
 *
 * Copyright 2013-2015 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

#ifndef DEVICE_H
#define DEVICE_H

#include "microej.h"

/**
 * LPC54S60x/LPC5460x IAP routine address
 * @see section 41.7 of the LPC54S60x/LPC5460x User Manual (UM10912)
 */
#define IAP_LOCATION              (0x03000205)

/**
 * LPC54S60x/LPC5460x ReadUID command
 * @see section 41.7.9 of the LPC54S60x/LPC5460x User Manual (UM10912)
 */
#define READ_UID_COMMAND          (58)

/**
 * LPC54S60x/LPC5460x Unique device ID register (128bits)
 * @see section 41.7.9 of the LPC54S60x/LPC5460x User Manual (UM10912)
 */
#define UNIQUE_DEVICE_ID_SIZE     (128/8)

/**
 * LPC54S60x/LPC5460x IAP pointer to function type
 * @see section 41.7 of the LPC54S60x/LPC5460x User Manual (UM10912)
 */
typedef void (*IAP)(uint32_t[], uint32_t[]);

/**
 * LPC54S60x/LPC5460x IAP status codes
 * @see section 41.7.14 of the LPC54S60x/LPC5460x User Manual (UM10912)
 */
typedef enum _iap_status_codes {
  CMD_SUCCESS,
  INVALID_COMMAND,
  SRC_ADDR_ERROR,
  DST_ADDR_ERROR,
  SRC_ADDR_NOT_MAPPED,
  DST_ADDR_NOT_MAPPED,
  COUNT_ERROR,
  INVALID_SECTOR,
  SECTOR_NOT_BLANK,
  SECTOR_NOT_PREPARED_FOR_WRITE_OPERATION,
  COMPARE_ERROR,
  BUSY
} iap_status_codes;

#endif

