/*
* C
*
* Copyright 2016 IS2T. All rights reserved.
* For demonstration purpose only.
* IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
*/

/* Includes ------------------------------------------------------------------*/
#include "fsl_gpio.h"
#include "pin_mux.h"

#include "LLLEDS_impl.h"

/* Definitions----------------------------------------------------------------*/
#define NUMBER_OF_LEDS	3

typedef enum {
    LED1 = 0,
    LED2 = 1,
    LED3 = 2
} Led_TypeDef;

/* Global --------------------------------------------------------------------*/

static const uint8_t LED_PORTn[NUMBER_OF_LEDS] = {BOARD_LED1_GPIO_PORT,
                                                 BOARD_LED2_GPIO_PORT,
                                                 BOARD_LED3_GPIO_PORT};
static const uint8_t LED_PINn[NUMBER_OF_LEDS] = {BOARD_LED1_GPIO_PIN,
                                                BOARD_LED2_GPIO_PIN,
                                                BOARD_LED3_GPIO_PIN};

/* Private functions ---------------------------------------------------------*/

static Led_TypeDef get_Led(int32_t ledID)
{
    switch(ledID) {
    default:
    case 0: return LED1;
    case 1: return LED2;
    case 2: return LED3;
    }
}

void Led_On(Led_TypeDef Led)
{
    GPIO_WritePinOutput(GPIO, LED_PORTn[Led], LED_PINn[Led], 0);
}

void Led_Off(Led_TypeDef Led)
{
    GPIO_WritePinOutput(GPIO, LED_PORTn[Led], LED_PINn[Led], 1);
}

/* API -----------------------------------------------------------------------*/

int32_t LLLEDS_IMPL_initialize(void)
{
    BOARD_InitLedPins();

    CLOCK_EnableClock(kCLOCK_Gpio2);
    CLOCK_EnableClock(kCLOCK_Gpio3);

    /* Define the init structure for the output LED pin*/
    gpio_pin_config_t led_config = {
        kGPIO_DigitalOutput, 1,
    };

    /* Init output LED GPIO. */
    GPIO_PinInit(GPIO, LED_PORTn[LED1], LED_PINn[LED1], &led_config);

    GPIO_PinInit(GPIO, LED_PORTn[LED2], LED_PINn[LED2], &led_config);

    GPIO_PinInit(GPIO, LED_PORTn[LED3], LED_PINn[LED3], &led_config);

    GPIO_SetPinsOutput(GPIO, 3, 1 << LED_PINn[LED1] | 1 << LED_PINn[LED2]);

	return 3;
}

int32_t LLLEDS_IMPL_getIntensity(int32_t ledID)
{
	// not available
	return LLLEDS_MAX_INTENSITY;
}

void LLLEDS_IMPL_setIntensity(int32_t ledID, int32_t intensity)
{
	if (intensity == LLLEDS_MIN_INTENSITY)
	{
		Led_Off(get_Led(ledID));
	}
	else
	{
		Led_On(get_Led(ledID));
	}
}
